==> AdvancedContent-v.0.3.4.tgz: AdvancedContent/lang/en_US.php <==
<?php

$lang['AdvancedContent']        = "Advanced Content";
$lang['installed']              = "Module AdvancedContent %s installed";
$lang['uninstalled']            = "Module AdvancedContent %s uninstalled";
$lang['upgraded']               = "Module AdvancedContent upgraded to %s";
$lang['postinstall']            = "Module AdvancedContent %s installed.";
$lang['postuninstall']          = "Module AdvancedContent %s uninstalled.";
$lang['confirmuninstall']       = "Do you really want uninstall the module AdvancedContent?";
$lang['error_duplicatecontent'] = "<em><strong>Notice:</strong> {content block='%s' ... } is ambigous. Block names must be unique. <br />This block is disabled. Only first block will be shown. Check your page template and chose a different value of param 'block'.</em>";
$lang['error_basicattrib']      = "<em><strong>Notice:</strong> Cannot use basic content property name '%s' as value of param 'block'. <br />This block is disabled. Check your page template and chose a different value of param 'block'.</em>";
$lang['error_expiredate']       = "End date must be later than start date.";
$lang['youareintext']           = "Current directory";
$lang['dimensions']             = "Imagesize";
$lang['size']                   = "Filesize";
$lang['inherit_from_parent']    = "Inherit from parent";
$lang['none']                   = "none";
$lang['invalid']                = "invalid";
$lang['yes']                    = "Yes";
$lang['no']                     = "No";
$lang['frontendaccess']         = "Frontend access";
$lang['redirectpage']           = "Redirect Page if no access";
$lang['showloginform']          = "Show login form";
$lang['registeredusers']        = "Registered users only";
$lang['block']                  = "Block";
$lang['useexpiredate']          = "Use expire date";
$lang['startdate']              = "Start Date";
$lang['enddate']                = "End Date";
$lang['blockcontent']           = "Block Content";
$lang['setpageinactive']        = "Set Page to Inactive";
$lang['deletepage']             = "Delete Page";
$lang['uninstallaction']        = "Uninstall action";
$lang['setcontent1']            = "Set all Pages to type Content";
$lang['setcontent2']            = "Set all Pages to type Content and remove additional content blocks";
$lang['prefsupdated']           = "Preferences updated";
$lang['fileoperations']         = "File operations";
$lang['uploadnewfile']          = "Upload a new file";
$lang['createnewdir']           = "Create a new directory";
$lang['uploadfile']             = "Upload";
$lang['createdir']              = "Create";
$lang['success']                = "Ok";
$lang['error']                  = "Error";
$lang['fileuploaded']           = "File uploaded";
$lang['nodirname']              = "No dirname provided";
$lang['direxists']              = "Dirname already exists";
$lang['newdircreated']          = "New dir successfully created";
$lang['newdirfailed']           = "An error occured trying to create dir";
$lang['nofile']                 = "No file was uploaded";
$lang['filetoobig']             = "Uploaded file is too big";
$lang['containsillegalchars']   = "Filename contains one or more illegal characters (',\",+,*,\\,/,&,$)";
$lang['uploadfailed']           = "Error moving uploaded file into place";
$lang['confirmdelete']          = "Are you sure to delete the file %s?";
$lang['deletefilesuccess']      = "was successfully deleted";
$lang['deletefilefailed']       = "could not be deleted";
$lang['deletesubdirfailed']     = "could not be deleted";
$lang['deletesubdirsuccess']    = "was successfully deleted";
$lang['confirmdeletedir']       = "Are you sure to delete the directory %s?";
$lang['deletedir']              = "Delete empty subdir";
$lang['deletefile']             = "Delete File";
$lang['restrictdirs']           = "Restrict user's dir access";
$lang['showfilemanagement']     = "Show filemanagement options";
$lang['showthumbnailfiles']     = "Show thumbnails";
$lang['allowscaling']           = "Allow on-the-fly resizing of uploaded images";
$lang['scalingwidth']           = "Scaling width";
$lang['scalingheight']          = "Scaling height";
$lang['defaultdimensions']      = "Default dimensions";
$lang['auto']                   = "Auto";
$lang['relativeurls']           = "Relative urls";
$lang['filepickerstyle']        = "Filepicker style";
$lang['filepickersize']         = "Filepicker size";
$lang['filenameonly']           = "Show filenames";
$lang['thumbnailsonly']         = "Show thumbnails";
$lang['showthumbnailfilestext'] = "Show thumbnail-files as regular files";
$lang['filenameandthumbnails']  = "Show both filenames and thumbnails";
$lang['scalingheight']          = "Scaling height";
$lang['makethumbnail']          = "Create thumbnails";
$lang['filepickersettings']     = "FilePicker settings";
$lang['resizeto']               = "Resize image to";
$lang['keepaspectratio']        = "Keep aspect ratio";
$lang['allowupscaling']         = "Allow upscaling";
$lang['decimaldelimiter']       = ".";
$lang['thousanddelimiter']      = ",";
$lang['dirnotfound']            = "Directory '%s' not found!";
$lang['selectimage']            = "Browse images";
$lang['selectfile']             = "Browse files";

?>

==> AdvancedContent-v.0.5.1.tgz: AdvancedContent/lang/en_US.php <==
<?php

$lang['AdvancedContent']        = "Advanced Content";
$lang['installed']              = "Module AdvancedContent %s installed";
$lang['uninstalled']            = "Module AdvancedContent %s uninstalled";
$lang['upgraded']               = "Module AdvancedContent upgraded to %s";
$lang['postinstall']            = "Module AdvancedContent %s installed.";
$lang['postuninstall']          = "Module AdvancedContent %s uninstalled.";
$lang['confirmuninstall']       = "Do you really want uninstall the module AdvancedContent?";
$lang['error_duplicatecontent'] = "<em><strong>Notice:</strong> {content block='%s' ... } is ambigous. Block names must be unique. <br />This block is disabled. Only first block will be shown. Check your page template and chose a different value of param 'block'.</em>";
$lang['notice_duplicatecontent']= "<em><strong>Notice:</strong> This block is used multiple times in template. You only see the first block here.</em>";
$lang['error_basicattrib']      = "<em><strong>Notice:</strong> Cannot use basic content property name '%s' as value of param 'block'. <br />This block is disabled. Check your page template and chose a different value of param 'block'.</em>";
$lang['error_expiredate']       = "End date must be later than start date.";
$lang['youareintext']           = "Current directory";
$lang['dimensions']             = "Imagesize";
$lang['size']                   = "Filesize";
$lang['inherit_from_parent']    = "Inherit from parent";
$lang['none']                   = "none";
$lang['invalid']                = "invalid";
$lang['invalid_blocktype']      = "<em><strong>Notice:</strong> Invalid value '%s' of param block_type in block '%s'.<br />Check your page template.</em>";
$lang['yes']                    = "Yes";
$lang['no']                     = "No";
$lang['frontendaccess']         = "Frontend access";
$lang['redirectpage']           = "Redirect Page if no access";
$lang['showloginform']          = "Show login form";
$lang['registeredusers']        = "Registered users only";
$lang['block']                  = "Block";
$lang['useexpiredate']          = "Use expire date";
$lang['startdate']              = "Start Date";
$lang['enddate']                = "End Date";
$lang['blockcontent']           = "Block Content";
$lang['setpageinactive']        = "Set Page to Inactive";
$lang['deletepage']             = "Delete Page";
$lang['uninstallaction']        = "Uninstall action";
$lang['setcontent1']            = "Set all Pages to type Content";
$lang['setcontent2']            = "Set all Pages to type Content and remove additional content blocks";
$lang['prefsupdated']           = "Preferences updated";
$lang['fileoperations']         = "File operations";
$lang['uploadnewfile']          = "Upload a new file";
$lang['createnewdir']           = "Create a new directory";
$lang['uploadfile']             = "Upload";
$lang['createdir']              = "Create";
$lang['success']                = "Ok";
$lang['error']                  = "Error";
$lang['fileuploaded']           = "File '%s' uploaded";
$lang['nodirname']              = "No dirname provided";
$lang['direxists']              = "Dirname '%s' already exists";
$lang['newdircreated']          = "New dir '%s' successfully created";
$lang['newdirfailed']           = "An error occured trying to create dir '%s'";
$lang['nofile']                 = "No file was uploaded";
$lang['filetoobig']             = "Uploaded file '%s' is too big";
$lang['containsillegalchars']   = "Filename '%s' contains one or more illegal characters (',\",+,*,\\,/,&,$)";
$lang['uploadfailed']           = "Error moving uploaded file '%s' into place";
$lang['confirmdelete']          = "Are you sure to delete the file \'%s\'?";
$lang['deletefilesuccess']      = "File '%s' was successfully deleted";
$lang['deletefilefailed']       = "File '%s' could not be deleted";
$lang['deletesubdirfailed']     = "Dir '%s' could not be deleted";
$lang['deletesubdirsuccess']    = "Dir '%s' was successfully deleted";
$lang['confirmdeletedir']       = "Are you sure to delete the directory \'%s\'?";
$lang['deletedir']              = "Delete empty subdir";
$lang['deletefile']             = "Delete File";
$lang['restrictdirs']           = "Restrict user's dir access";
$lang['showfilemanagement']     = "Show filemanagement options";
$lang['showthumbnailfiles']     = "Show thumbnails";
$lang['allowscaling']           = "Allow on-the-fly resizing of uploaded images";
$lang['scalingwidth']           = "Scaling width";
$lang['scalingheight']          = "Scaling height";
$lang['defaultdimensions']      = "Default dimensions";
$lang['auto']                   = "Auto";
$lang['relativeurls']           = "Relative urls";
$lang['filepickerstyle']        = "Filepicker style";
$lang['filepickersize']         = "Filepicker size";
$lang['filenameonly']           = "Show filenames";
$lang['thumbnailsonly']         = "Show thumbnails";
$lang['showthumbnailfilestext'] = "Show thumbnail-files as regular files";
$lang['filenameandthumbnails']  = "Show both filenames and thumbnails";
$lang['scalingheight']          = "Scaling height";
$lang['makethumbnail']          = "Create thumbnails";
$lang['filepickersettings']     = "FilePicker settings";
$lang['resizeto']               = "Resize image to";
$lang['keepaspectratio']        = "Keep aspect ratio";
$lang['allowupscaling']         = "Allow upscaling";
$lang['decimaldelimiter']       = ".";
$lang['thousanddelimiter']      = ",";
$lang['dirnotfound']            = "Directory '%s' not found!";
$lang['selectimage']            = "Browse images";
$lang['selectfile']             = "Browse files";
$lang['deletepages']            = "Delete all pages of type AdvancedContent";
$lang['usemimetype']            = "Use mime-type to get file type";
$lang['importpages']            = "Set all Pages of type content to type AdvancedContent.";
$lang['pagesimported']          = "All content pages set to AdvancedContent.";
$lang['confirmimport']          = "Do you really want to change the content type of all content pages?";
$lang['nomimetype']             = "No mime-type function available or not configured properly. This feature is disabled.";
$lang['toggle_message']         = "Hide this message";
$lang['contentsettings']        = "Default AdvancedContent settings";
$lang['redirectparams']         = "URL params to append when redirecting";
$lang['evaluatesmarty']         = "Use smarty to process the params";
$lang['noimagefile']            = "'%s' is not an image file";
$lang['filetypenotallowed']     = "Filetype '%s' is not allowed";

?>
